@@ -2,7 +2,6 @@ import pytest
 from nerdchess import pieces
 from nerdchess.config import colors
 from nerdchess.move import Move
-from nerdchess.boardmove import BoardMove
 
 
 @pytest.fixture(scope='class', params=[
@@ -37,4 +36,4 @@ class TestPieces():
 
         assert isinstance(allowed_moves, list)
         for move in allowed_moves:
-            assert isinstance(move, BoardMove)
+            assert isinstance(move, Move)
